@@ -896,6 +896,146 @@ An "empty comment" does not consume following blocks. (An empty comment is ".."
 So this block is not "lost", despite its indentation.
 <<
 
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_niconico_directive(self):
+        str = """\
+Hatena "niconico" notation.
+
+.. niconico:: sm9
+"""
+        exp_str = """\
+Hatena "niconico" notation.
+
+[niconico:sm9]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_google_directive(self):
+        str = """\
+Hatena "google" notation.
+
+.. google:: rst2hatena
+
+.. google:: Guid van Rossum
+    :target: image
+
+.. google:: Python
+    :target: news
+"""
+        exp_str = """\
+Hatena "google" notation.
+
+[google:rst2hatena]
+[google:image:Guid van Rossum]
+[google:news:Python]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_amazon_directive(self):
+        str = """\
+Hatena "amazon" notation.
+
+.. amazon:: Python
+"""
+        exp_str = """\
+Hatena "amazon" notation.
+
+[amazon:Python]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_wikipedia_directive(self):
+        str = """\
+Hatena "wikipedia" notation.
+
+.. wikipedia:: Python
+
+.. wikipedia:: Python
+    :lang: en
+"""
+        exp_str = """\
+Hatena "wikipedia" notation.
+
+[wikipedia:Python]
+[wikipedia:en:Python]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_twitter_directive(self):
+        str = """\
+Hatena "twitter" notation.
+
+.. twitter:: 88453766201880576
+    :type: title
+
+.. twitter:: 88453766201880576
+    :type: tweet
+
+.. twitter:: 88453766201880576
+    :type: detail
+
+.. twitter:: 88453766201880576
+    :type: tree
+
+.. twitter:: @naoina
+"""
+        exp_str = """\
+Hatena "twitter" notation.
+
+[twitter:88453766201880576:title]
+[twitter:88453766201880576:tweet]
+[twitter:88453766201880576:detail]
+[twitter:88453766201880576:tree]
+[twitter:@naoina]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_map_directive(self):
+        str = """\
+Hatena "map" notation.
+
+.. map::
+    :x: 139.6983
+    :y: 35.6514
+
+.. map::
+    :x: 139.6983
+    :y: 35.6514
+    :type: map
+
+.. map::
+    :x: 139.6983
+    :y: 35.6514
+    :type: satellite
+    :height: 300
+
+.. map::
+    :x: 139.6983
+    :y: 35.6514
+    :type: hybrid
+    :width: 300
+"""
+        exp_str = """\
+Hatena "map" notation.
+
+map:x139.6983y35.6514
+map:x139.6983y35.6514:map
+map:x139.6983y35.6514:satellite:h300
+map:x139.6983y35.6514:hybrid:w300
 """
         output = publish_string(str, writer=self.writer)
         self.assertEqual(exp_str, output)
@@ -908,4 +1048,3 @@ if __name__ == '__main__':
         GrowlTestRunner().run(suite)
     except:
         unittest.main()
-    
